#
# Fedora spec file for php-symfony-securiy-acl
#
# Copyright (c) 2016 Shawn Iwinski <shawn@iwin.ski>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     symfony
%global github_name      security-acl
%global github_version   2.8.0
%global github_commit    4a3f7327ad215242c78f6564ad4ea6d2db1b8347

%global composer_vendor  symfony
%global composer_project security-acl

# "php": ">=5.3.9"
%global php_min_ver 5.3.9
# "symfony/phpunit-bridge": "~2.7|~3.0.0"
# "symfony/security-core": "~2.4|~3.0.0"
#     NOTE: Min version not 2.7 because autoloader required
%global symfony_min_ver 2.7.1
%global symfony_max_ver 4.0
# "doctrine/common": "~2.2"
#     NOTE: Min version not 2.2 because autoloader required
%global doctrine_common_min_ver 2.5.0
%global doctrine_common_max_ver 3.0
# "doctrine/dbal": "~2.2"
#     NOTE: Min version not 2.2 because autoloader required
%global doctrine_dbal_min_ver 2.5.4
%global doctrine_dbal_max_ver 3.0
# "psr/log": "~1.0"
#     NOTE: Min version not 1.0 because autoloader required
%global psr_log_min_ver 1.0.1
%global psr_log_max_ver 2.0

%global bootstrap 0

%if %{bootstrap}
%global with_tests 0
%else
# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}
%endif

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-%{composer_vendor}-%{composer_project}
Version:       %{github_version}
Release:       4%{?github_release}%{?dist}
Summary:       Symfony Security Component - ACL (Access Control List)

Group:         Development/Libraries
License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}
Source0:       %{url}/archive/%{github_commit}/%{name}-%{github_version}-%{github_commit}.tar.gz

BuildArch:     noarch
# Tests
%if %{with_tests}
## composer.json
BuildRequires: php(language)                       >= %{php_min_ver}
BuildRequires: php-composer(doctrine/common)       <  %{doctrine_common_max_ver}
BuildRequires: php-composer(doctrine/common)       >= %{doctrine_common_min_ver}
BuildRequires: php-composer(doctrine/dbal)         <  %{doctrine_dbal_max_ver}
BuildRequires: php-composer(doctrine/dbal)         >= %{doctrine_dbal_min_ver}
BuildRequires: php-composer(phpunit/phpunit)
BuildRequires: php-composer(psr/log)               <  %{psr_log_max_ver}
BuildRequires: php-composer(psr/log)               >= %{psr_log_min_ver}
BuildRequires: php-composer(symfony/security-core) <  %{symfony_max_ver}
BuildRequires: php-composer(symfony/security-core) >= %{symfony_min_ver}
## phpcompatinfo (computed from version 2.8.0)
BuildRequires: php-pcre
BuildRequires: php-reflection
BuildRequires: php-spl
## Autoloader
BuildRequires: php-composer(fedora/autoloader)
%endif

# composer.json
Requires:      php(language) >= %{php_min_ver}
Requires:      php-composer(symfony/security-core) <  %{symfony_max_ver}
Requires:      php-composer(symfony/security-core) >= %{symfony_min_ver}
# phpcompatinfo (computed from version 2.8.0)
Requires:      php-pcre
Requires:      php-reflection
Requires:      php-spl
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Weak dependencies
%if 0%{?fedora} >= 21
Suggests:      php-composer(doctrine/dbal)
Suggests:      php-composer(symfony/finder)
%endif

# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

# Extracted from Symfony as of version 2.8.0
Conflicts:     php-symfony-security < 2.8.0

%description
%{summary}.

Autoloader: %{phpdir}/Symfony/Component/Security/Acl/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}


%build
: Create autoloader
cat <<'AUTOLOAD' | tee autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 */
require_once '%{phpdir}/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Symfony\\Component\\Security\\Acl\\', __DIR__);

\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/Doctrine/DBAL/autoload.php',
    array(
        '%{phpdir}/Symfony3/Component/Security/autoload.php',
        '%{phpdir}/Symfony/Component/Security/autoload.php',
    ),
));

\Fedora\Autoloader\Dependencies::optional(array(
    '%{phpdir}/Doctrine/DBAL/autoload.php',
    array(
        '%{phpdir}/Symfony3/Component/Finder/autoload.php',
        '%{phpdir}/Symfony/Component/Finder/autoload.php',
    ),
));
AUTOLOAD


%install
mkdir -p %{buildroot}%{phpdir}/Symfony/Component/Security/Acl
cp -rp * %{buildroot}%{phpdir}/Symfony/Component/Security/Acl/


%check
%if %{with_tests}
: Create tests bootstrap
cat <<'BOOTSTRAP' | tee bootstrap.php
<?php
require_once '%{buildroot}%{phpdir}/Symfony/Component/Security/Acl/autoload.php';

\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/Doctrine/Common/autoload.php',
    '%{phpdir}/Psr/Log/autoload.php',
));
BOOTSTRAP

%{_bindir}/phpunit --verbose --bootstrap bootstrap.php

: Upstream tests
RETURN_CODE=0
PHPUNIT=$(which phpunit)
for PHP_EXEC in "" %{?rhel:php54 php55} php56 php70 php71 php72; do
    if [ -z "$PHP_EXEC" ] || which $PHP_EXEC; then
        $PHP_EXEC $PHPUNIT --verbose --bootstrap bootstrap.php || RETURN_CODE=1
     fi
 done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{phpdir}/Symfony/Component/Security/Acl
%exclude %{phpdir}/Symfony/Component/Security/Acl/*.md
%exclude %{phpdir}/Symfony/Component/Security/Acl/composer.json
%exclude %{phpdir}/Symfony/Component/Security/Acl/LICENSE
%exclude %{phpdir}/Symfony/Component/Security/Acl/phpunit.*
%exclude %{phpdir}/Symfony/Component/Security/Acl/Tests


%changelog
* Thu Sep 21 2017 Shawn Iwinski <shawn@iwin.ski> - 2.8.0-4
- Add max versions to BuildRequires
- Switch autoloader to fedora/autoloader
- Remove Conflicts for Suggests
- Test with SCLs if available

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri May 20 2016 Shawn Iwinski <shawn@iwin.ski> - 2.8.0-1
- Initial package
